@@ -1,9 +1,9 @@
 package Class::MOP::Method::Constructor;
-$Class::MOP::Method::Constructor::VERSION = '2.1213';
+our $VERSION = '2.1405';
+
 use strict;
 use warnings;
 
-use Carp         'confess';
 use Scalar::Util 'blessed', 'weaken';
 use Try::Tiny;
 
@@ -133,7 +133,7 @@ Class::MOP::Method::Constructor - Method Meta Object for constructors
 
 =head1 VERSION
 
-version 2.1213
+version 2.1405
 
 =head1 SYNOPSIS
 
