@@ -1,10 +1,10 @@
 package Class::MOP::Package;
-$Class::MOP::Package::VERSION = '2.1213';
+our $VERSION = '2.1405';
+
 use strict;
 use warnings;
 
-use Scalar::Util 'blessed', 'reftype', 'weaken';
-use Carp         'confess';
+use Scalar::Util 'blessed', 'weaken';
 use Devel::GlobalDestruction 'in_global_destruction';
 use Module::Runtime 'module_notional_filename';
 use Package::Stash;
@@ -283,7 +283,7 @@ Class::MOP::Package - Package Meta Object
 
 =head1 VERSION
 
-version 2.1213
+version 2.1405
 
 =head1 DESCRIPTION
 
