@@ -1,5 +1,6 @@
 package Moose::Exception::ValidationFailedForTypeConstraint;
-$Moose::Exception::ValidationFailedForTypeConstraint::VERSION = '2.1213';
+our $VERSION = '2.1405';
+
 use Moose;
 extends 'Moose::Exception';
 with 'Moose::Exception::Role::Attribute';
@@ -18,15 +19,14 @@ has 'type' => (
 
 sub _build_message {
     my $self = shift;
-    my $error_message = $self->type->get_message($self->value);
 
-    if( $self->is_attribute_set )
-    {
-        my $attribute_name = $self->attribute->name;
-        return "Attribute ($attribute_name) does not pass the type constraint because: $error_message";
-    }
+    my $error = $self->type->get_message( $self->value );
 
-    return $error_message;
+    return $error unless $self->is_attribute_set;
+
+    my $attribute_name = $self->attribute->name;
+    return
+        "Attribute ($attribute_name) does not pass the type constraint because: $error";
 }
 
 1;
