@@ -1,13 +1,11 @@
 package Moose::Meta::Attribute::Native::Trait;
-$Moose::Meta::Attribute::Native::Trait::VERSION = '2.1213';
+our $VERSION = '2.1405';
+
 use Moose::Role;
 use Module::Runtime 'require_module';
-use List::MoreUtils qw( any uniq );
 use Moose::Deprecated;
-use Moose::Util;
-use Moose::Util::TypeConstraints;
-
 use Moose::Util 'throw_exception';
+use Moose::Util::TypeConstraints;
 
 requires '_helper_type';
 
@@ -179,7 +177,7 @@ Moose::Meta::Attribute::Native::Trait - Shared role for native delegation traits
 
 =head1 VERSION
 
-version 2.1213
+version 2.1405
 
 =head1 BUGS
 
