@@ -1,16 +1,9 @@
 package Moose::Meta::Method::Accessor::Native::Hash::defined;
-BEGIN {
-  $Moose::Meta::Method::Accessor::Native::Hash::defined::AUTHORITY = 'cpan:STEVAN';
-}
-{
-  $Moose::Meta::Method::Accessor::Native::Hash::defined::VERSION = '2.1005';
-}
+our $VERSION = '2.1405';
 
 use strict;
 use warnings;
 
-use Scalar::Util qw( looks_like_number );
-
 use Moose::Role;
 
 with 'Moose::Meta::Method::Accessor::Native::Reader',
