@@ -1,10 +1,9 @@
 package Moose::Meta::Method::Accessor::Native::Hash::exists;
-$Moose::Meta::Method::Accessor::Native::Hash::exists::VERSION = '2.1213';
+our $VERSION = '2.1405';
+
 use strict;
 use warnings;
 
-use Scalar::Util qw( looks_like_number );
-
 use Moose::Role;
 
 with 'Moose::Meta::Method::Accessor::Native::Reader',
