@@ -1,13 +1,9 @@
 package Moose::Meta::Method::Accessor::Native::Hash::values;
-BEGIN {
-  $Moose::Meta::Method::Accessor::Native::Hash::values::AUTHORITY = 'cpan:STEVAN';
-}
-$Moose::Meta::Method::Accessor::Native::Hash::values::VERSION = '2.1210';
+our $VERSION = '2.1405';
+
 use strict;
 use warnings;
 
-use Scalar::Util qw( looks_like_number );
-
 use Moose::Role;
 
 with 'Moose::Meta::Method::Accessor::Native::Reader';
