@@ -1,49 +1,50 @@
-
 package Moose::Meta::Method::Delegation;
-BEGIN {
-  $Moose::Meta::Method::Delegation::AUTHORITY = 'cpan:STEVAN';
-}
-{
-  $Moose::Meta::Method::Delegation::VERSION = '2.1005';
-}
+our $VERSION = '2.1405';
 
 use strict;
 use warnings;
 
-use Carp         'confess';
 use Scalar::Util 'blessed', 'weaken';
 
-use base 'Moose::Meta::Method',
+use parent 'Moose::Meta::Method',
          'Class::MOP::Method::Generated';
 
+use Moose::Util 'throw_exception';
 
 sub new {
     my $class   = shift;
     my %options = @_;
 
     ( exists $options{attribute} )
-        || confess "You must supply an attribute to construct with";
+        || throw_exception( MustSupplyAnAttributeToConstructWith => params => \%options,
+                                                                    class  => $class
+                          );
 
     ( blessed( $options{attribute} )
             && $options{attribute}->isa('Moose::Meta::Attribute') )
-        || confess
-        "You must supply an attribute which is a 'Moose::Meta::Attribute' instance";
+        || throw_exception( MustSupplyAMooseMetaAttributeInstance => params => \%options,
+                                                                     class  => $class
+                          );
 
     ( $options{package_name} && $options{name} )
-        || confess
-        "You must supply the package_name and name parameters $Class::MOP::Method::UPGRADE_ERROR_TEXT";
+        || throw_exception( MustSupplyPackageNameAndName => params => \%options,
+                                                            class  => $class
+                          );
 
     ( $options{delegate_to_method} && ( !ref $options{delegate_to_method} )
             || ( 'CODE' eq ref $options{delegate_to_method} ) )
-        || confess
-        'You must supply a delegate_to_method which is a method name or a CODE reference';
+        || throw_exception( MustSupplyADelegateToMethod => params => \%options,
+                                                           class  => $class
+                          );
 
     exists $options{curried_arguments}
         || ( $options{curried_arguments} = [] );
 
     ( $options{curried_arguments} &&
         ( 'ARRAY' eq ref $options{curried_arguments} ) )
-        || confess 'You must supply a curried_arguments which is an ARRAY reference';
+        || throw_exception( MustSupplyArrayRefAsCurriedArguments => params     => \%options,
+                                                                    class_name => $class
+                          );
 
     my $self = $class->_new( \%options );
 
@@ -91,21 +92,20 @@ sub _initialize_body {
         my $instance = shift;
         my $proxy    = $instance->$accessor();
 
-        my $error
-            = !defined $proxy                 ? ' is not defined'
-            : ref($proxy) && !blessed($proxy) ? qq{ is not an object (got '$proxy')}
-            : undef;
-
-        if ($error) {
-            $self->throw_error(
-                "Cannot delegate $handle_name to $method_to_call because "
-                    . "the value of "
-                    . $self->associated_attribute->name
-                    . $error,
-                method_name => $method_to_call,
-                object      => $instance
-            );
+        if( !defined $proxy ) {
+            throw_exception( AttributeValueIsNotDefined => method     => $self,
+                                                           instance   => $instance,
+                                                           attribute  => $self->associated_attribute,
+                           );
         }
+        elsif( ref($proxy) && !blessed($proxy) ) {
+            throw_exception( AttributeValueIsNotAnObject => method      => $self,
+                                                            instance    => $instance,
+                                                            attribute   => $self->associated_attribute,
+                                                            given_value => $proxy
+                           );
+        }
+
         unshift @_, @{ $self->curried_arguments };
         $proxy->$method_to_call(@_);
     };
@@ -141,13 +141,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Moose::Meta::Method::Delegation - A Moose Method metaclass for delegation methods
 
 =head1 VERSION
 
-version 2.1005
+version 2.1405
 
 =head1 DESCRIPTION
 
@@ -200,13 +202,55 @@ constructor.
 
 See L<Moose/BUGS> for details on reporting bugs.
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Moose is maintained by the Moose Cabal, along with the help of many contributors. See L<Moose/CABAL> and L<Moose/CONTRIBUTORS> for details.
+=over 4
+
+=item *
+
+Stevan Little <stevan.little@iinteractive.com>
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=item *
+
+Jesse Luehrs <doy@tozt.net>
+
+=item *
+
+Shawn M Moore <code@sartak.org>
+
+=item *
+
+יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Florian Ragwitz <rafl@debian.org>
+
+=item *
+
+Hans Dieter Pearcey <hdp@weftsoar.net>
+
+=item *
+
+Chris Prather <chris@prather.org>
+
+=item *
+
+Matt S Trout <mst@shadowcat.co.uk>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Infinity Interactive, Inc..
+This software is copyright (c) 2006 by Infinity Interactive, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
