@@ -1,11 +1,5 @@
-
 package Moose::Object;
-BEGIN {
-  $Moose::Object::AUTHORITY = 'cpan:STEVAN';
-}
-{
-  $Moose::Object::VERSION = '2.1005';
-}
+our $VERSION = '2.1405';
 
 use strict;
 use warnings;
@@ -16,6 +10,8 @@ use MRO::Compat ();
 use Scalar::Util ();
 use Try::Tiny ();
 
+use Moose::Util ();
+
 use if ( not our $__mx_is_compiled ), 'Moose::Meta::Class';
 use if ( not our $__mx_is_compiled ), metaclass => 'Moose::Meta::Class';
 
@@ -32,9 +28,7 @@ sub BUILDARGS {
     my $class = shift;
     if ( scalar @_ == 1 ) {
         unless ( defined $_[0] && ref $_[0] eq 'HASH' ) {
-            Class::MOP::class_of($class)->throw_error(
-                "Single parameters to new() must be a HASH ref",
-                data => $_[0] );
+            Moose::Util::throw_exception( "SingleParamsToNewMustBeHashRef" );
         }
         return { %{ $_[0] } };
     }
@@ -94,6 +88,10 @@ sub DESTROY {
 
     local $?;
 
+    # < doy> if the destructor is being called because an exception is thrown, then $@ will be set
+    # < doy> but if DEMOLISH does an eval which succeeds, that will clear $@
+    # < doy> which is broken
+    # < doy> try::tiny implicitly localizes $@ in the try block, which fixes that
     Try::Tiny::try {
         $self->DEMOLISHALL(Devel::GlobalDestruction::in_global_destruction);
     }
@@ -121,7 +119,7 @@ sub does {
     my $class = Scalar::Util::blessed($self) || $self;
     my $meta = Class::MOP::Class->initialize($class);
     (defined $role_name)
-        || $meta->throw_error("You must supply a role name to does()");
+        || Moose::Util::throw_exception( DoesRequiresRoleName => class_name => $meta->name );
     return 1 if $meta->can('does_role') && $meta->does_role($role_name);
     return 0;
 }
@@ -141,13 +139,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Moose::Object - The base object for Moose
 
 =head1 VERSION
 
-version 2.1005
+version 2.1405
 
 =head1 DESCRIPTION
 
@@ -216,13 +216,55 @@ method in the inheritance hierarchy.
 
 See L<Moose/BUGS> for details on reporting bugs.
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Moose is maintained by the Moose Cabal, along with the help of many contributors. See L<Moose/CABAL> and L<Moose/CONTRIBUTORS> for details.
+=over 4
+
+=item *
+
+Stevan Little <stevan.little@iinteractive.com>
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=item *
+
+Jesse Luehrs <doy@tozt.net>
+
+=item *
+
+Shawn M Moore <code@sartak.org>
+
+=item *
+
+יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Florian Ragwitz <rafl@debian.org>
+
+=item *
+
+Hans Dieter Pearcey <hdp@weftsoar.net>
+
+=item *
+
+Chris Prather <chris@prather.org>
+
+=item *
+
+Matt S Trout <mst@shadowcat.co.uk>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Infinity Interactive, Inc..
+This software is copyright (c) 2006 by Infinity Interactive, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
